==> ownershiptransfer-1.0.1.tar.gz: ownershiptransfer/l10n/gl.js <==
OC.L10N.register(
    "ownershiptransfer",
    {
    "Upload (max. %s)" : "Envío (máx. %s)",
    "Ownership Transfer" : "Transferencia de propiedade",
    "App to transfer the ownership of a user to another" : "Aplicación para transferir a propiedade dun usuario para outro",
    "Transfer data from one user to another." : "Transferir datos dun usuario para outro.",
    "Source User" : "Usuario de orixe",
    "Destination User" : "Usuario de destino",
    "The source user must be different from the destination user!" : "O usuario de orixe debe ser diferente do usuario de destino!",
    "Files" : "Ficheiros",
    "Calendar" : "Calendario",
    "Contacts" : "Contactos",
    "You must select at least one app to transfer data from." : "Debe seleccionar polo menos unha aplicación dende a que transferir datos.",
    "Loading..." : "Cargando…",
    "Transfer" : "Transferir",
    "Files transfer launched. The source and destination users will receive a notification once it is completed." : "Iniciou a transferencia de ficheiros. Os usuarios de orixe e destino recibirán unha notificación unha vez que se complete.",
    "Files transfer failed" : "Produciuse un fallo na transferencia de ficheiros",
    "Calendar transfer completed successfully" : "A transferencia do calendario completouse correctamente",
    "Calendar transfer failed" : "Produciuse un fallo na transferencia do calendario",
    "Contacts transfer completed successfully" : "A transferencia de contactos completouse correctamente",
    "Contacts transfer failed" : "Produciuse un fallo na transferencia de contactos",
    "The transfer has been canceled." : "A transferencia foi cancelada.",
    "No Calendars" : "Non hai ningún calendario",
    "Could not fetch calendars" : "Non foi posíbel recuperar os calendarios",
    "This user doesn't have any calendar yet." : "Este usuario aínda non ten ningún calendario.",
    "Shared" : "Compartido",
    "_%n event_::_%n events_" : ["%n evento","%n eventos"],
    "Choose calendar" : "Escoller calendario",
    "Choose the calendar to transfer" : "Escolla o calendario para transferir",
    "Cancel" : "Cancelar",
    "Choose" : "Escoller",
    "Calendar Transfer" : "Transferencia de calendario",
    "You can transfer every calendar from the source user to the destination user, or choose a specific one to transfer." : "Pode transferir todos os calendarios do usuario de orixe ao usuario de destino ou escoller un específico para transferir.",
    "Choose a calendar" : "Escoller un calendario",
    "Confirm the transfer" : "Confirmar a transferencia",
    "Files:" : "Ficheiros:",
    "Calendar:" : "Calendario:",
    "Contacts:" : "Contactos:",
    "All the selected data will be moved from the source user to the destination user." : "Todos os datos seleccionados moveranse do usuario de orixe ao usuario de destino.",
    "The source user won't have access to this data anymore." : "O usuario de orixe xa non terá acceso a estes datos.",
    "The files sharing settings will be preserved. Please note that the files transfer might take some time to complete." : "Conservaranse os axustes de compartición de ficheiros. Teña en conta que a transferencia de ficheiros pode levar algún tempo en completarse.",
    "The calendar sharing settings might change. You should check the calendar shares after the transfer if you want to keep them." : "É posíbel que os axustes de compartición do calendario cambie. Debe consultar as comparticións do calendario após a transferencia se quere conservalas.",
    "The contacts sharing settings might change. You should check the address books shares after the transfer if you want to keep them." : "Os axustes de compartición de contactos pode cambiar. Debe comprobar as comparticións dos cadernos de enderezos após a transferencia se quere conservalas.",
    "Confirm" : "Confirmar",
    "All the files" : "Todos os ficheiros",
    "All the calendars" : "Todos os calendarios",
    "All the contacts" : "Todos os contactos",
    "No Address Books" : "Non hai ningún caderno de enderezos",
    "Could not fetch address books" : "Non foi posíbel recuperar os cadernos de enderezos",
    "This user doesn't have any address book yet." : "Este usuario aínda non ten ningún caderno de enderezos.",
    "Could not fetch contacts" : "Non foi posíbel recuperar os contactos",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Choose address book" : "Escoller o caderno de enderezos",
    "Choose the address book to transfer" : "Escolla o caderno de enderezos para transferir",
    "Contacts Transfer" : "Transferencia de contactos",
    "You can transfer every contact from the source user to the destination user, or choose an address book to transfer." : "Pode transferir todos os contactos do usuario de orixe ao usuario de destino ou escoller un caderno de enderezos para transferir.",
    "Choose an address book" : "Escoller un caderno de enderezos",
    "No Files" : "Non hai ningún ficheiro",
    "Could not fetch files" : "Non foi posíbel recuperar os ficheiros",
    "This user doesn't have any file yet." : "Este usuario aínda non ten ningún ficheiro.",
    "Error code {code} - {errorMessage}" : "Código de erro {code} — {errorMessage}",
    "Choose folder" : "Escoller cartafol",
    "Choose the folder to transfer" : "Escolla o cartafol para transferir",
    "Files Transfer" : "Transferencia de ficheiros",
    "You can transfer all the files from the source user to the destination user, or choose a specific folder to transfer." : "Pode transferir todos os ficheiros do usuario de orixe ao usuario de destino ou escoller un cartafol específico para transferir.",
    "Choose a folder" : "Escoller un cartafol",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Public share" : "Compartición pública",
    "Internal share" : "Compartición interna"
},
"nplurals=2; plural=(n != 1);");

==> ownershiptransfer-1.2.1.tar.gz: ownershiptransfer/l10n/gl.js <==
OC.L10N.register(
    "ownershiptransfer",
    {
    "Upload (max. %s)" : "Envío (máx. %s)",
    "Ownership Transfer" : "Transferencia de propiedade",
    "App to transfer the ownership of a user to another" : "Aplicación para transferir a propiedade dun usuario para outro",
    "Transfer data from one user to another." : "Transferir datos dun usuario para outro.",
    "Source User" : "Usuario de orixe",
    "Destination User" : "Usuario de destino",
    "The source user must be different from the destination user!" : "O usuario de orixe debe ser diferente do usuario de destino!",
    "Files" : "Ficheiros",
    "Calendar" : "Calendario",
    "Contacts" : "Contactos",
    "You must select at least one app to transfer data from." : "Debe seleccionar polo menos unha aplicación desde a que transferir datos.",
    "Loading..." : "Cargando…",
    "Transfer" : "Transferir",
    "Files transfer launched. The source and destination users will receive a notification once it is completed." : "Iniciou a transferencia de ficheiros. Os usuarios de orixe e destino recibirán unha notificación unha vez que se complete.",
    "Files transfer failed" : "Produciuse un fallo na transferencia de ficheiros",
    "Calendar transfer completed successfully" : "A transferencia do calendario completouse correctamente",
    "Calendar transfer failed" : "Produciuse un fallo na transferencia do calendario",
    "Contacts transfer completed successfully" : "A transferencia de contactos completouse correctamente",
    "Contacts transfer failed" : "Produciuse un fallo na transferencia de contactos",
    "The transfer has been canceled." : "A transferencia foi cancelada.",
    "No Calendars" : "Non hai ningún calendario",
    "Could not fetch calendars" : "Non foi posíbel recuperar os calendarios",
    "This user doesn't have any calendar yet." : "Este usuario aínda non ten ningún calendario.",
    "Shared" : "Compartido",
    "_%n event_::_%n events_" : ["%n evento","%n eventos"],
    "Choose calendar" : "Escoller calendario",
    "Choose the calendar to transfer" : "Escolla o calendario para transferir",
    "Cancel" : "Cancelar",
    "Choose" : "Escoller",
    "Calendar Transfer" : "Transferencia de calendario",
    "You can transfer every calendar from the source user to the destination user, or choose a specific one to transfer." : "Pode transferir todos os calendarios do usuario de orixe ao usuario de destino ou escoller un específico para transferir.",
    "Choose a calendar" : "Escoller un calendario",
    "Confirm the transfer" : "Confirmar a transferencia",
    "Files:" : "Ficheiros:",
    "Calendar:" : "Calendario:",
    "Contacts:" : "Contactos:",
    "All the selected data will be moved from the source user to the destination user." : "Todos os datos seleccionados moveranse do usuario de orixe ao usuario de destino.",
    "The source user won't have access to this data anymore." : "O usuario de orixe xa non terá acceso a estes datos.",
    "The files sharing settings will be preserved. Please note that the files transfer might take some time to complete." : "Conservaranse os axustes de compartición de ficheiros. Teña en conta que a transferencia de ficheiros pode levar algún tempo en completarse.",
    "The calendar sharing settings might change. You should check the calendar shares after the transfer if you want to keep them." : "É posíbel que os axustes de compartición do calendario cambie. Debe consultar as comparticións do calendario após a transferencia se quere conservalas.",
    "The contacts sharing settings might change. You should check the address books shares after the transfer if you want to keep them." : "Os axustes de compartición de contactos pode cambiar. Debe comprobar as comparticións dos cadernos de enderezos após a transferencia se quere conservalas.",
    "Confirm" : "Confirmar",
    "All the files" : "Todos os ficheiros",
    "All the calendars" : "Todos os calendarios",
    "All the contacts" : "Todos os contactos",
    "No Address Books" : "Non hai ningún caderno de enderezos",
    "Could not fetch address books" : "Non foi posíbel recuperar os cadernos de enderezos",
    "This user doesn't have any address book yet." : "Este usuario aínda non ten ningún caderno de enderezos.",
    "Could not fetch contacts" : "Non foi posíbel recuperar os contactos",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Choose address book" : "Escoller o caderno de enderezos",
    "Choose the address book to transfer" : "Escolla o caderno de enderezos para transferir",
    "Contacts Transfer" : "Transferencia de contactos",
    "You can transfer every contact from the source user to the destination user, or choose an address book to transfer." : "Pode transferir todos os contactos do usuario de orixe ao usuario de destino ou escoller un caderno de enderezos para transferir.",
    "Choose an address book" : "Escoller un caderno de enderezos",
    "No Files" : "Non hai ningún ficheiro",
    "Could not fetch files" : "Non foi posíbel recuperar os ficheiros",
    "This user doesn't have any file yet." : "Este usuario aínda non ten ningún ficheiro.",
    "Error code {code} - {errorMessage}" : "Código de erro {code} — {errorMessage}",
    "Choose folder" : "Escoller cartafol",
    "Choose the folder to transfer" : "Escolla o cartafol para transferir",
    "Files Transfer" : "Transferencia de ficheiros",
    "You can transfer all the files from the source user to the destination user, or choose a specific folder to transfer." : "Pode transferir todos os ficheiros do usuario de orixe ao usuario de destino ou escoller un cartafol específico para transferir.",
    "Choose a folder" : "Escoller un cartafol",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Public share" : "Compartición pública",
    "Internal share" : "Compartición interna"
},
"nplurals=2; plural=(n != 1);");
